// page-crm-data.component.ts
import { Component, ViewChild, ElementRef, AfterViewInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

@Component({
  selector: 'app-page-crm-data',
  standalone: true,
  imports: [CommonModule, FormsModule],
  templateUrl: './page-crm-data.html', // 确保路径正确
  styleUrls: ['./page-crm-data.scss']
})

export class PageCrmData implements AfterViewInit {
  // 标签相关数据
  sourceTags = [
    { name: '会议记录', active: true },
    { name: '客户合同', active: false },
    { name: '反馈表', active: false },
    { name: '培训资料', active: false }
  ];
  
  newTag = '';
  
  // 上传方式
  uploadMethods = [
    { name: '拍照', icon: 'camera', active: false },
    { name: '文件', icon: 'file', active: false },
    { name: '录音', icon: 'microphone', active: false },
    { name: '文本', icon: 'keyboard', active: false }
  ];
  
  // 上传状态
  uploadStatus = {
    visible: false,
    progress: 0,
    message: '',
    success: false
  };
  
  // 历史记录
  historyItems = [
    { name: 'Q3销售报告.pdf', type: 'pdf', size: 4.2, date: '2023-10-15' },
    { name: '客户数据.xlsx', type: 'excel', size: 3.1, date: '2023-10-14' },
    { name: '会议纪要.docx', type: 'word', size: 1.7, date: '2023-10-13' },
    { name: '用户反馈.csv', type: 'csv', size: 2.3, date: '2023-10-12' }
  ];
  
  filteredHistory = [...this.historyItems];
  searchTerm = '';
  
  // 训练结果
  trainingResults = [
    { title: '销售预测模型', time: '2.3小时', status: 'completed', icon: 'brain' },
    { title: '情感分析模型', time: '1.5小时', status: 'training', icon: 'comments' },
    { title: '趋势预测模型', time: '3.1小时', status: 'completed', icon: 'chart-line' },
    { title: '客户服务模型', time: '4.2小时', status: 'error', icon: 'robot' }
  ];
  
  // 数据看板
  dashboardStats = [
    { label: '新增数据', value: 42, trend: 12, trendUp: true, icon: 'file-medical' },
    { label: '处理中', value: 18, trend: 5, trendUp: false, icon: 'cogs' },
    { label: '训练时间', value: '1.8h', trend: 23, trendUp: true, icon: 'clock' },
    { label: '完成率', value: '76%', trend: 8, trendUp: true, icon: 'check-circle' }
  ];
  
  // 选择标签
  selectTag(tag: any) {
    this.sourceTags.forEach(t => t.active = false);
    tag.active = true;
  }
  
  // 添加新标签
  addTag() {
    if (this.newTag.trim()) {
      this.sourceTags.push({ name: this.newTag.trim(), active: true });
      this.selectTag(this.sourceTags[this.sourceTags.length - 1]);
      this.newTag = '';
    }
  }
  
  // 选择上传方式
  selectMethod(method: any) {
    this.uploadMethods.forEach(m => m.active = false);
    method.active = true;
  }
  
  // 上传数据
  uploadData() {
    const selectedTag = this.sourceTags.find(t => t.active)?.name || '未知';
    const selectedMethod = this.uploadMethods.find(m => m.active)?.name || '未选择';
    
    this.uploadStatus = {
      visible: true,
      progress: 0,
      message: `正在上传: ${selectedTag} (方式: ${selectedMethod})`,
      success: false
    };
    
    // 模拟上传进度
    const interval = setInterval(() => {
      this.uploadStatus.progress += Math.floor(Math.random() * 10);
      
      if (this.uploadStatus.progress >= 100) {
        this.uploadStatus.progress = 100;
        clearInterval(interval);
        
        // 上传完成
        setTimeout(() => {
          this.uploadStatus.message = `<i class="fas fa-check-circle"></i> 上传成功: ${selectedTag} (方式: ${selectedMethod})`;
          this.uploadStatus.success = true;
          
          // 添加新项目到历史记录
          this.addHistoryItem(selectedTag, selectedMethod);
          
          // 3秒后隐藏状态
          setTimeout(() => {
            this.uploadStatus.visible = false;
          }, 3000);
        }, 500);
      }
    }, 200);
  }
  
  // 添加历史记录
  addHistoryItem(tagName: string, methodName: string) {
    const fileType = this.getFileExtension(methodName);
    
    this.historyItems.unshift({
      name: `${tagName}.${fileType}`,
      type: fileType,
      size: +(Math.random() * 5).toFixed(1),
      date: this.getCurrentDate()
    });
    
    this.filterHistory();
  }
  
  // 获取文件扩展名
  getFileExtension(method: string): string {
    switch(method) {
      case '拍照': return 'jpg';
      case '文件': return 'pdf';
      case '录音': return 'mp3';
      case '文本': return 'txt';
      default: return 'dat';
    }
  }
  
  // 获取当前日期
  getCurrentDate(): string {
    const now = new Date();
    const year = now.getFullYear();
    const month = String(now.getMonth() + 1).padStart(2, '0');
    const day = String(now.getDate()).padStart(2, '0');
    return `${year}-${month}-${day}`;
  }
  
  // 搜索历史记录
  filterHistory() {
    if (!this.searchTerm.trim()) {
      this.filteredHistory = [...this.historyItems];
      return;
    }
    
    const term = this.searchTerm.toLowerCase();
    this.filteredHistory = this.historyItems.filter(item => 
      item.name.toLowerCase().includes(term) || 
      item.type.toLowerCase().includes(term) ||
      item.date.includes(term)
    );
  }
  
  // 随机更新数据看板
  ngAfterViewInit() {
    setInterval(() => {
      this.dashboardStats = this.dashboardStats.map(stat => {
        if (typeof stat.value === 'number') {
          const change = Math.floor(Math.random() * 5) - 2; // -2 到 2 之间的随机数
          const newValue = Math.max(0, stat.value + change);
          return { ...stat, value: newValue };
        }
        return stat;
      });
    }, 5000);
  }
}